/**
 * Copyright (c) 2000-2011 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.samplesignin.portlet;

import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.portlet.NoRedirectActionResponse;
import com.liferay.portal.kernel.struts.PortletActionInvoker;
import com.liferay.portal.kernel.util.ParamUtil;
import com.liferay.portal.kernel.util.Validator;
import com.liferay.portal.util.PortalUtil;
import com.liferay.util.bridges.mvc.MVCPortlet;

import java.io.IOException;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.PortletConfig;
import javax.portlet.PortletException;

/**
 * @author Brian Wing Shun Chan
 */
public class SignInPortlet extends MVCPortlet {

	@Override
	public void processAction(
			ActionRequest actionRequest, ActionResponse actionResponse)
		throws IOException, PortletException {

		String className = "com.liferay.portlet.login.action.LoginAction";
		PortletConfig portletConfig = getPortletConfig();
		NoRedirectActionResponse noRedirectActionResponse =
			new NoRedirectActionResponse(actionResponse);

		try {
			PortletActionInvoker.processAction(
				className, portletConfig, actionRequest,
				noRedirectActionResponse);
		}
		catch (Exception e) {
			_log.error(e, e);
		}

		String login = ParamUtil.getString(actionRequest, "login");
		String password = ParamUtil.getString(actionRequest, "password");
		String rememberMe = ParamUtil.getString(actionRequest, "rememberMe");

		if (Validator.isNull(noRedirectActionResponse.getRedirectLocation())) {
			actionResponse.setRenderParameter("login", login);
			actionResponse.setRenderParameter("rememberMe", rememberMe);
		}
		else {
			String redirect =
				PortalUtil.getPathMain() + "/portal/login?login=" + login +
					"&password=" + password + "&rememberMe=" + rememberMe;

			actionResponse.sendRedirect(redirect);
		}
	}

	private static Log _log = LogFactoryUtil.getLog(SignInPortlet.class);

}